@@ -27,7 +27,7 @@ class CreateInterestedParties:
 
     @classmethod
     def person(self, type_person):
-        ip_person = ip[type_person]
+        ip_person = ip()[type_person]
         # if ip_person[name_first]:
         #     pass
         print(ip_person)
